/*
 * Funambol is a mobile platform developed by Funambol, Inc. 
 * Copyright (C) 2003 - 2007 Funambol, Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by
 * the Free Software Foundation with the addition of the following permission 
 * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
 * WORK IN WHICH THE COPYRIGHT IS OWNED BY FUNAMBOL, FUNAMBOL DISCLAIMS THE 
 * WARRANTY OF NON INFRINGEMENT  OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License 
 * along with this program; if not, see http://www.gnu.org/licenses or write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301 USA.
 * 
 * You can contact Funambol, Inc. headquarters at 643 Bair Island Road, Suite 
 * 305, Redwood City, CA 94063, USA, or at email address info@funambol.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License
 * version 3, these Appropriate Legal Notices must retain the display of the
 * "Powered by Funambol" logo. If the display of the logo is not reasonably 
 * feasible for technical reasons, the Appropriate Legal Notices must display
 * the words "Powered by Funambol".
 */
package com.funambol.syncclient.sps.pocketpc.util;

import java.io.*;
import java.util.StringTokenizer;

import com.funambol.syncclient.sps.pocketpc.RapiDB;

/**
 * This class imports a Windows CE database from a CSV file. Volume and database
 * names are passed on the command line. Optionally, the database is deleted and
 * recreated. The comma separated values are read from the standard input stream.
 *
 * @version $Id: CEDatabaseImport.java,v 1.6 2007/11/28 10:45:02 nichele Exp $
 */
public class CEDatabaseImport {


    /**
     * Syntax:
     *  com.funambol.syncclient.sps.common.util.CEDatabaseImport [-create] volume database key_field status_field
     * @param args the command line arguments
     */
    public static void main(String[] args) throws Exception {
        boolean create      = false;
        int     argc        = 0    ;
        int     keyField    = 1    ;
        int     statusField = 2    ;

        if (args.length < 4) {
            syntax();
            System.exit(-1);
        }

        if ((args.length == 5) && ("-create".equals(args[0]))) {
            create = true;
            argc = 1;
        }

        RapiDB db = new RapiDB(args[argc++], args[argc++]);

        keyField    = Integer.parseInt(args[argc++]);
        statusField = Integer.parseInt(args[argc++]);

        if (create) {
            if (db.openDB(keyField, statusField, keyField) == true) {
                db.deleteDB();
            }

            if (!db.createDB(keyField, statusField)) {
                System.out.println("Error creating the database!");
                System.exit(-1);
            }
        }

        if (!db.openDB(keyField, statusField, keyField)) {
            System.out.println("Error creating the database!");
            System.exit(-1);
        }

        BufferedReader reader = new BufferedReader( new InputStreamReader(System.in));

        int i=0;
        Object[] data;
        String key;
        String line;
        StringTokenizer stk;
        while((line = reader.readLine()) != null) {
            if (line.startsWith("#") || (line.trim().length() == 0)) {
                continue;
            }

            System.out.println("processing.... " + line);

            stk = new StringTokenizer(line, "|");

            //
            // First token is the id
            //
            key = stk.nextToken();

            data = new Object[stk.countTokens()];
            i = 0;
            while (stk.hasMoreTokens()) {
                data[i++] = stk.nextToken();
            }

            db.storeRecord(key, data);
        }

        db.closeDB();
        reader.close();
    }

    private static void syntax() {
        System.out.println("Wrong syntax.");
        System.out.println("Syntax:");
        System.out.println("com.funambol.syncclient.sps.common.util.CEDatabaseImport [-create] volume database");
    }

}
